==> nextcloud-31.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dashboard/l10n/en_GB.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking.",
    "Weather" : "Weather",
    "Status" : "Status",
    "Good morning" : "Good morning",
    "Good morning, {name}" : "Good morning, {name}",
    "Good afternoon" : "Good afternoon",
    "Good afternoon, {name}" : "Good afternoon, {name}",
    "Good evening" : "Good evening",
    "Good evening, {name}" : "Good evening, {name}",
    "Hello" : "Hello",
    "Hello, {name}" : "Hello, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Happy birthday 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Happy birthday, {name} 🥳🤩🎂🎉",
    "\"{title} icon\"" : "\"{title} icon\"",
    "Customize" : "Customise",
    "Edit widgets" : "Edit widgets",
    "Get more widgets from the App Store" : "Get more widgets from the App Store",
    "Weather service" : "Weather service",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information.",
    "Weather data from Met.no" : "Weather data from Met.no",
    "geocoding with Nominatim" : "geocoding with Nominatim",
    "elevation data from OpenTopoData" : "elevation data from OpenTopoData"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/dashboard/l10n/en_GB.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking.",
    "Weather" : "Weather",
    "Status" : "Status",
    "Good morning" : "Good morning",
    "Good morning, {name}" : "Good morning, {name}",
    "Good afternoon" : "Good afternoon",
    "Good afternoon, {name}" : "Good afternoon, {name}",
    "Good evening" : "Good evening",
    "Good evening, {name}" : "Good evening, {name}",
    "Hello" : "Hello",
    "Hello, {name}" : "Hello, {name}",
    "Happy birthday 🥳🤩🎂🎉" : "Happy birthday 🥳🤩🎂🎉",
    "Happy birthday, {name} 🥳🤩🎂🎉" : "Happy birthday, {name} 🥳🤩🎂🎉",
    "Customize" : "Customise",
    "Edit widgets" : "Edit widgets",
    "Get more widgets from the App Store" : "Get more widgets from the App Store",
    "Weather service" : "Weather service",
    "For your privacy, the weather data is requested by your {productName} server on your behalf so the weather service receives no personal information." : "For your privacy, the weather data is requested by your {productName} server on your behalf so the weather service receives no personal information.",
    "Weather data from Met.no" : "Weather data from Met.no",
    "geocoding with Nominatim" : "geocoding with Nominatim",
    "elevation data from OpenTopoData" : "elevation data from OpenTopoData",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information."
},
"nplurals=2; plural=(n != 1);");
